==> batchcomputecli-0.0.10.tar.gz: batchcomputecli-0.0.10/batchcomputecli/services/oss_client.py <==
from ..externals.simple_oss import *
from .config import getConfigs,COMMON
from .util import format_sec_date


def _get_host(region=None):
    if not region:
        raise Exception('Invalid oss region or endpoint: %s' % region)

    if '.' in region:
        k = len('batchcompute.')
        region = region[ k : region.index('.', k) ]

    return 'oss-%s.aliyuncs.com' % region

def _get_client(opt=None):
    opt = opt or getConfigs(COMMON, ['region','endpoint', 'accesskeyid','accesskeysecret'])
    host = _get_host(opt.get('region') or opt.get('endpoint'))
    id = opt.get('accesskeyid')
    key = opt.get('accesskeysecret')

    return SimpleOss(host, id, key)


def _parse_oss_path(p):
    if not p.startswith('oss://'):
        raise Exception('Invalid oss path:%s' % p)

    k = p.index('/', len('oss://'))
    return {'bucket': p[len('oss://'): k], 'prefix': p[k+1:]}

def check(pre=''):
    client = _get_client()
    
    obj = _parse_oss_path(pre)
    bucket = str(obj.get('bucket'))
    prefix = str(obj.get('prefix'))

    flag = client.exists(bucket, prefix)
    if not flag:
        raise Exception('Invalid oss path : %s' % pre)


def upload(oss_path, file):
    client = _get_client()

    obj = _parse_oss_path(oss_path)
    bucket = str(obj.get('bucket'))
    prefix = str(obj.get('prefix'))

    client.upload(bucket, file ,prefix)

def get(pre='', file=None):
    client = _get_client()

    obj = _parse_oss_path(pre)
    bucket = str(obj.get('bucket'))
    prefix = str(obj.get('prefix'))

    if file:
        client.download(bucket, prefix, file)
    else:
        v=client.download_str(bucket, prefix)
        return v

def list(pre=''):
    client = _get_client()

    obj = _parse_oss_path(pre)
    bucket = str(obj.get('bucket'))
    prefix = str(obj.get('prefix'))

    arr = []
    try:
        t = client.list(bucket, prefix)
        for k in t:
            arr.append({
                'log_path': 'oss://%s/%s'%(bucket,k),
                'time' :__get_inst_log_time(k)
            })
    except Exception,e:
        raise Exception('Fetch log list error : %s' % e)
    return arr



def __get_inst_log_time(s):
    v = s[-len('1443505842'):]
    v = int(v)
    return format_sec_date(v)

==> batchcomputecli-0.0.11.tar.gz: batchcomputecli-0.0.11/batchcomputecli/services/oss_client.py <==
from ..externals.simple_oss import *
from .config import getConfigs,COMMON
from .util import format_sec_date


def _get_host(region=None):
    if not region:
        raise Exception('Invalid oss region or endpoint: %s' % region)

    if '.' in region:
        k = len('batchcompute.')
        region = region[ k : region.index('.', k) ]

    return 'oss-%s.aliyuncs.com' % region

def _get_client(opt=None):
    opt = opt or getConfigs(COMMON, ['region','endpoint', 'accesskeyid','accesskeysecret'])
    host = _get_host(opt.get('region') or opt.get('endpoint'))
    id = opt.get('accesskeyid')
    key = opt.get('accesskeysecret')

    return SimpleOss(host, id, key)


def _parse_oss_path(p):
    if not p.startswith('oss://'):
        raise Exception('Invalid oss path:%s' % p)

    k = p.index('/', len('oss://'))
    return {'bucket': p[len('oss://'): k], 'prefix': p[k+1:]}

def check(pre=''):
    client = _get_client()
    
    obj = _parse_oss_path(pre)
    bucket = str(obj.get('bucket'))
    prefix = str(obj.get('prefix'))

    flag = client.exists(bucket, prefix)
    if not flag:
        raise Exception('Invalid oss path : %s' % pre)


def upload(oss_path, file):
    client = _get_client()

    obj = _parse_oss_path(oss_path)
    bucket = str(obj.get('bucket'))
    prefix = str(obj.get('prefix'))

    client.upload(bucket, file ,prefix)

def get(pre='', file=None):
    client = _get_client()

    obj = _parse_oss_path(pre)
    bucket = str(obj.get('bucket'))
    prefix = str(obj.get('prefix'))

    if file:
        client.download(bucket, prefix, file)
    else:
        v=client.download_str(bucket, prefix)
        return v

def list(pre=''):
    client = _get_client()

    obj = _parse_oss_path(pre)
    bucket = str(obj.get('bucket'))
    prefix = str(obj.get('prefix'))

    arr = []
    try:
        t = client.list(bucket, prefix, verbose=True)

        for k in t:
            arr.append({
                'log_path': 'oss://%s/%s'%(bucket, k[0]),
                'time' : __get_inst_log_time(k[0]),
                'size' : k[1]
            })
    except Exception,e:
        raise Exception('Oops, cannot fetch log list, it may be OSS AccessDenied')
    return arr



def __get_inst_log_time(s):
    s = str(s)
    v = s[-len('1443505842'):]
    v = int(v)
    return format_sec_date(v)
